<?php return array(
  'package' => array(
    'type' => 'language',
    'name' => 'english',
    'version' => '8.0.0',
    'revision' => '$Revision$',
    'path' => 'application/languages/en',
    'repository' => 'socialengine.com',
    'title' => 'English',
    'author' => 'SocialEngine Core',
    'license' => 'http://www.socialengine.com/license/',
    'directories' => array(
      'application/languages/en',
    )
  )
) ?>
